#[repr(C)]pub enum EngineReaction<'a> {
Journaled(Journaled<'a>),
Directive(Directive<'a>),
}Variants
Journaled(Journaled<'a>)
A notice that something has just happened within the engine.
Directive(Directive<'a>)
An order for something that must now happen outside the engine.