pub enum IgnoreReason {
Show 25 variants
Consumed,
Malformed,
UnhandledContext,
Duplicate,
Superseded,
NotForUs,
NoRoute,
HopLimitReached,
LoopPrevented,
RouteUnresponsive,
OtherInstance,
UnknownLink,
LinkPhaseMismatch,
LinkRttError(LinkRttError),
DecryptFailed,
ProofInvalid,
UnknownIdentity,
LinkRequestsRefused,
PermissionDenied,
RateLimited,
CapacityExhausted,
RequestTooLarge,
StrategyDeclined,
UnmatchedResponse,
IfacRefused,
}Variants
Consumed
Malformed
UnhandledContext
Duplicate
Superseded
NotForUs
NoRoute
HopLimitReached
LoopPrevented
RouteUnresponsive
OtherInstance
UnknownLink
LinkPhaseMismatch
LinkRttError(LinkRttError)
DecryptFailed
ProofInvalid
UnknownIdentity
LinkRequestsRefused
Link requests are disabled for the destination.
PermissionDenied
RateLimited
CapacityExhausted
RequestTooLarge
StrategyDeclined
The app’s declared acceptance policy declined an offer that was well-formed and deliverable.
UnmatchedResponse
A resource response advertisement has no matching pending request.
IfacRefused