pub struct IdentityEncryptionPublicKey(/* private fields */);Expand description
X25519 public keys are used outside of identity work as well. This newtype is used as a brand to avoid accidental crossing.
Implementations
Sourceimpl IdentityEncryptionPublicKey
impl IdentityEncryptionPublicKey
pub const fn new(key: X25519PublicKey) -> IdentityEncryptionPublicKey
pub const fn as_x25519(&self) -> &X25519PublicKey
pub const fn as_bytes(&self) -> &[u8; 32]