pub enum ConnectionState {
Initializing,
Connected,
Degraded,
Reconnecting,
Failed,
Disconnected,
Disabled,
Unknown,
}Variants
Initializing
Connected
Degraded
Reconnecting
Failed
Disconnected
Disabled
A deliberate, reversible off state that retains the interface slot and learned routes while closing the wire and discarding egress.
Unknown