pub struct RecursivePathRequests<C>where
C: RecursivePathRequestTable,{ /* private fields */ }Expand description
RNS 1.4.2 Transport.discovery_path_requests.
Implementations
Sourceimpl<C> RecursivePathRequests<C>where
C: RecursivePathRequestTable,
impl<C> RecursivePathRequests<C>where
C: RecursivePathRequestTable,
pub fn begin( &mut self, destination: DestinationHash, requesting_interface: InterfaceId, expires_at: InstantMillis, ) -> RecursiveOutcome
pub fn take_requester( &mut self, destination: &DestinationHash, ) -> Option<InterfaceId>
Sourcepub fn contains(&self, destination: &DestinationHash) -> bool
pub fn contains(&self, destination: &DestinationHash) -> bool
Whether a recursive path request is in flight for destination; like a pending request, it exempts the destination from ingress limiting.
pub fn cull_expired(&mut self, now: InstantMillis)
pub fn earliest_expiry_at(&self) -> Option<InstantMillis>