Module persistence_snapshots

Module persistence_snapshots 

Structs

PersistedStateSnapshot
The sealed region images of one snapshot pass and the engine instant they were taken at — the timebase high-water a flush of these images should record.
SelfRatchetSnapshot
SelfRatchetsSnapshot
One sealed self-ratchet blob per tracked destination, zeroized on drop.

Functions

self_ratchet_identity_label
snapshot_persisted_state
snapshot_self_ratchet
snapshot_self_ratchets