pub struct DeviceReport {
pub detected: bool,
pub r_frequency: Option<u32>,
pub r_bandwidth: Option<u32>,
pub r_txpower: Option<u8>,
pub r_sf: Option<u8>,
pub r_cr: Option<u8>,
pub r_state: Option<u8>,
pub fw_maj: Option<u8>,
pub fw_min: Option<u8>,
}Fields
detected: boolr_frequency: Option<u32>r_bandwidth: Option<u32>r_txpower: Option<u8>r_sf: Option<u8>r_cr: Option<u8>r_state: Option<u8>fw_maj: Option<u8>fw_min: Option<u8>Implementations
Sourceimpl DeviceReport
impl DeviceReport
pub fn apply(&mut self, command: u8, payload: &[u8])
pub fn all_radio_params_present(&self) -> bool
Sourcepub fn radio_validated(&self, config: &RadioConfig) -> bool
pub fn radio_validated(&self, config: &RadioConfig) -> bool
RNS permits a missing frequency report but otherwise requires frequency within 100 Hz, exact bandwidth, TX power and spreading factor, and the radio powered on.
Sourcepub fn firmware_ok(&self) -> Option<bool>
pub fn firmware_ok(&self) -> Option<bool>
RNS panics on an old reported firmware; the host interface only warns.
pub const fn firmware_version(&self) -> Option<FirmwareVersion>