pub struct Links<C>where
C: LinkTable,{ /* private fields */ }Implementations
Sourceimpl<C> Links<C>where
C: LinkTable,
impl<C> Links<C>where
C: LinkTable,
pub fn track_initiated( &mut self, link: InitiatedLink, ) -> Result<(), TrackLinkError>
pub fn track_responding( &mut self, link: RespondingLink, ) -> Result<(), TrackLinkError>
pub fn link_count_via(&self, interface: InterfaceId) -> usize
pub fn active_link_count(&self) -> usize
pub fn phase_for(&self, link_id: &LinkId) -> Option<&LinkPhase>
pub fn has_local_link(&self, link_id: &LinkId) -> bool
pub fn activate_initiated( &mut self, link_id: &LinkId, key: LinkKey, activation: &LinkActivation, now: InstantMillis, ) -> Result<(), LinkActivationError>
pub fn activate_responding( &mut self, link_id: &LinkId, rtt: RttMillis, attached_interface: InterfaceId, now: InstantMillis, ) -> Result<DestinationHash, LinkActivationError>
Sourcepub fn set_resource_strategy(
&mut self,
link_id: &LinkId,
strategy: ResourceStrategy,
) -> Result<(), LinkActivationError>
pub fn set_resource_strategy( &mut self, link_id: &LinkId, strategy: ResourceStrategy, ) -> Result<(), LinkActivationError>
RNS 1.4.2 Link.set_resource_strategy: how this link answers inbound resource advertisements from now on.
Sourcepub fn note_resource_concluded(
&mut self,
link_id: &LinkId,
window: usize,
eifr: u64,
)
pub fn note_resource_concluded( &mut self, link_id: &LinkId, window: usize, eifr: u64, )
RNS 1.4.2 Link.resource_concluded’s memory. The window and expected in-flight rate an incoming transfer ended with, inherited by the next transfer this link accepts.
pub fn note_identified(&mut self, link_id: &LinkId, identity: IdentityHash)
pub fn note_inbound(&mut self, link_id: &LinkId, now: InstantMillis)
pub fn note_outbound(&mut self, link_id: &LinkId, now: InstantMillis)
pub fn note_keepalive_sent(&mut self, link_id: &LinkId, now: InstantMillis)
pub fn keepalive_echo_due(&self, link_id: &LinkId, now: InstantMillis) -> bool
pub fn remove(&mut self, link_id: &LinkId) -> bool
pub fn pop_stale(&mut self, now: InstantMillis) -> Option<LinkId>
pub fn pop_due_keepalive(&mut self, now: InstantMillis) -> Option<DueKeepalive>
pub fn pop_overdue(&mut self, now: InstantMillis) -> Option<OverdueLink>
pub fn earliest_timeout_at(&self) -> Option<InstantMillis>
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool