pub struct InterfacePathRequestLimits<C>where
C: InterfacePathRequestLimitTable,{ /* private fields */ }Implementations
Sourceimpl<C> InterfacePathRequestLimits<C>where
C: InterfacePathRequestLimitTable,
impl<C> InterfacePathRequestLimits<C>where
C: InterfacePathRequestLimitTable,
pub fn should_egress_limit( &self, interface: InterfaceId, now: InstantMillis, policy: PathRequestEgressControl, ) -> bool
pub fn record_egress(&mut self, interface: InterfaceId, now: InstantMillis)
Sourcepub fn record_and_should_limit(
&mut self,
interface: InterfaceId,
now: InstantMillis,
) -> bool
pub fn record_and_should_limit( &mut self, interface: InterfaceId, now: InstantMillis, ) -> bool
Record a path request on interface and report whether to drop its recursive discovery forward. This implements RNS 1.4.2 Interface.should_ingress_limit_pr, replacing the 48-sample sliding deque with an integer fixed window of the same span.
pub fn record_and_should_limit_with_policy( &mut self, interface: InterfaceId, now: InstantMillis, policy: IngressControlPolicy, ) -> bool
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool