pub struct PersistedStateSnapshot {
pub routing_table: Vec<u8>,
pub tunnels: Vec<u8>,
pub destination_identities: Vec<u8>,
pub taken_at: InstantMillis,
}Expand description
The sealed region images of one snapshot pass and the engine instant they were taken at — the timebase high-water a flush of these images should record.
Fields
routing_table: Vec<u8>tunnels: Vec<u8>destination_identities: Vec<u8>taken_at: InstantMillisAuto Trait Implementations
impl Freeze for PersistedStateSnapshot
impl RefUnwindSafe for PersistedStateSnapshot
impl Send for PersistedStateSnapshot
impl Sync for PersistedStateSnapshot
impl Unpin for PersistedStateSnapshot
impl UnsafeUnpin for PersistedStateSnapshot
impl UnwindSafe for PersistedStateSnapshot